# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Management")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class MdmAlertDataType(enum.IntEnum):
    STRING = 0
    BASE64 = 1
    BOOLEAN = 2
    INTEGER = 3

class MdmAlertMark(enum.IntEnum):
    NONE = 0
    FATAL = 1
    CRITICAL = 2
    WARNING = 3
    INFORMATIONAL = 4

class MdmSessionState(enum.IntEnum):
    NOT_STARTED = 0
    STARTING = 1
    CONNECTING = 2
    COMMUNICATING = 3
    ALERT_STATUS_AVAILABLE = 4
    RETRYING = 5
    COMPLETED = 6

_ns_module._register_MdmAlertDataType(MdmAlertDataType)
_ns_module._register_MdmAlertMark(MdmAlertMark)
_ns_module._register_MdmSessionState(MdmSessionState)

MdmAlert = _ns_module.MdmAlert
MdmSession = _ns_module.MdmSession
MdmSessionManager = _ns_module.MdmSessionManager



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class DisplayRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayRequest: ...
    def __new__(cls: typing.Type[DisplayRequest]) -> DisplayRequest:...
    def request_active(self) -> None: ...
    def request_release(self) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.activation
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking
import winsdk.windows.networking.sockets
import winsdk.windows.security.credentials
import winsdk.windows.security.cryptography.certificates
import winsdk.windows.storage.streams
import winsdk.windows.system

class VpnAppIdType(enum.IntEnum):
    PACKAGE_FAMILY_NAME = 0
    FULLY_QUALIFIED_BINARY_NAME = 1
    FILE_PATH = 2

class VpnAuthenticationMethod(enum.IntEnum):
    MSCHAPV2 = 0
    EAP = 1
    CERTIFICATE = 2
    PRESHARED_KEY = 3

class VpnChannelActivityEventType(enum.IntEnum):
    IDLE = 0
    ACTIVE = 1

class VpnChannelRequestCredentialsOptions(enum.IntFlag):
    NONE = 0
    RETRYING = 0x1
    USE_FOR_SINGLE_SIGN_IN = 0x2

class VpnCredentialType(enum.IntEnum):
    USERNAME_PASSWORD = 0
    USERNAME_OTP_PIN = 1
    USERNAME_PASSWORD_AND_PIN = 2
    USERNAME_PASSWORD_CHANGE = 3
    SMART_CARD = 4
    PROTECTED_CERTIFICATE = 5
    UN_PROTECTED_CERTIFICATE = 6

class VpnDataPathType(enum.IntEnum):
    SEND = 0
    RECEIVE = 1

class VpnDomainNameType(enum.IntEnum):
    SUFFIX = 0
    FULLY_QUALIFIED = 1
    RESERVED = 65535

class VpnIPProtocol(enum.IntEnum):
    NONE = 0
    TCP = 6
    UDP = 17
    ICMP = 1
    IPV6_ICMP = 58
    IGMP = 2
    PGM = 113

class VpnManagementConnectionStatus(enum.IntEnum):
    DISCONNECTED = 0
    DISCONNECTING = 1
    CONNECTED = 2
    CONNECTING = 3

class VpnManagementErrorStatus(enum.IntEnum):
    OK = 0
    OTHER = 1
    INVALID_XML_SYNTAX = 2
    PROFILE_NAME_TOO_LONG = 3
    PROFILE_INVALID_APP_ID = 4
    ACCESS_DENIED = 5
    CANNOT_FIND_PROFILE = 6
    ALREADY_DISCONNECTING = 7
    ALREADY_CONNECTED = 8
    GENERAL_AUTHENTICATION_FAILURE = 9
    EAP_FAILURE = 10
    SMART_CARD_FAILURE = 11
    CERTIFICATE_FAILURE = 12
    SERVER_CONFIGURATION = 13
    NO_CONNECTION = 14
    SERVER_CONNECTION = 15
    USER_NAME_PASSWORD = 16
    DNS_NOT_RESOLVABLE = 17
    INVALID_I_P = 18

class VpnNativeProtocolType(enum.IntEnum):
    PPTP = 0
    L2TP = 1
    IPSEC_IKEV2 = 2

class VpnPacketBufferStatus(enum.IntEnum):
    OK = 0
    INVALID_BUFFER_SIZE = 1

class VpnRoutingPolicyType(enum.IntEnum):
    SPLIT_ROUTING = 0
    FORCE_ALL_TRAFFIC_OVER_VPN = 1

Self = typing.TypeVar('Self')

class VpnAppId(winsdk.system.Object):
    value: str
    type: VpnAppIdType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnAppId: ...
    def __new__(cls: typing.Type[VpnAppId], type: VpnAppIdType, value: str) -> VpnAppId:...

class VpnChannel(winsdk.system.Object):
    plug_in_context: typing.Optional[winsdk.system.Object]
    configuration: typing.Optional[VpnChannelConfiguration]
    id: winsdk.system.UInt32
    system_health: typing.Optional[VpnSystemHealth]
    current_request_transport_context: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnChannel: ...
    def activate_foreground(self, package_relative_app_id: str, shared_context: typing.Optional[winsdk.windows.foundation.collections.ValueSet]) -> typing.Optional[winsdk.windows.foundation.collections.ValueSet]: ...
    def add_and_associate_transport(self, transport: typing.Optional[winsdk.system.Object], context: typing.Optional[winsdk.system.Object]) -> None: ...
    def append_vpn_receive_packet_buffer(self, decapsulated_packet_buffer: typing.Optional[VpnPacketBuffer]) -> None: ...
    def append_vpn_send_packet_buffer(self, encapsulated_packet_buffer: typing.Optional[VpnPacketBuffer]) -> None: ...
    def associate_transport(self, main_outer_tunnel_transport: typing.Optional[winsdk.system.Object], optional_outer_tunnel_transport: typing.Optional[winsdk.system.Object]) -> None: ...
    def flush_vpn_receive_packet_buffers(self) -> None: ...
    def flush_vpn_send_packet_buffers(self) -> None: ...
    def get_slot_type_for_transport_context(self, context: typing.Optional[winsdk.system.Object]) -> winsdk.windows.networking.sockets.ControlChannelTriggerStatus: ...
    def get_vpn_receive_packet_buffer(self) -> typing.Optional[VpnPacketBuffer]: ...
    def get_vpn_send_packet_buffer(self) -> typing.Optional[VpnPacketBuffer]: ...
    def log_diagnostic_message(self, message: str) -> None: ...
    @staticmethod
    def process_event_async(third_party_plug_in: typing.Optional[winsdk.system.Object], event: typing.Optional[winsdk.system.Object]) -> None: ...
    def replace_and_associate_transport(self, transport: typing.Optional[winsdk.system.Object], context: typing.Optional[winsdk.system.Object]) -> None: ...
    def request_credentials(self, cred_type: VpnCredentialType, is_retry: winsdk.system.Boolean, is_single_sign_on_credential: winsdk.system.Boolean, certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]) -> typing.Optional[VpnPickedCredential]: ...
    @typing.overload
    def request_credentials_async(self, cred_type: VpnCredentialType) -> winsdk.windows.foundation.IAsyncOperation[VpnCredential]: ...
    @typing.overload
    def request_credentials_async(self, cred_type: VpnCredentialType, cred_options: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[VpnCredential]: ...
    @typing.overload
    def request_credentials_async(self, cred_type: VpnCredentialType, cred_options: winsdk.system.UInt32, certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]) -> winsdk.windows.foundation.IAsyncOperation[VpnCredential]: ...
    def request_custom_prompt(self, custom_prompt: winsdk.windows.foundation.collections.IVectorView[IVpnCustomPrompt]) -> None: ...
    def request_custom_prompt_async(self, custom_prompt_element: winsdk.windows.foundation.collections.IVectorView[IVpnCustomPromptElement]) -> winsdk.windows.foundation.IAsyncAction: ...
    def request_vpn_packet_buffer(self, type: VpnDataPathType) -> typing.Optional[VpnPacketBuffer]: ...
    def set_allowed_ssl_tls_versions(self, tunnel_transport: typing.Optional[winsdk.system.Object], use_tls12: winsdk.system.Boolean) -> None: ...
    def set_error_message(self, message: str) -> None: ...
    def start(self, assigned_client_i_pv4list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], assigned_client_i_pv6list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], vpn_interface_id: typing.Optional[VpnInterfaceId], route_scope: typing.Optional[VpnRouteAssignment], namespace_scope: typing.Optional[VpnNamespaceAssignment], mtu_size: winsdk.system.UInt32, max_frame_size: winsdk.system.UInt32, optimize_for_low_cost_network: winsdk.system.Boolean, main_outer_tunnel_transport: typing.Optional[winsdk.system.Object], optional_outer_tunnel_transport: typing.Optional[winsdk.system.Object]) -> None: ...
    def start_existing_transports(self, assigned_client_i_pv4list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], assigned_client_i_pv6list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], vpn_interface_id: typing.Optional[VpnInterfaceId], assigned_routes: typing.Optional[VpnRouteAssignment], assigned_domain_name: typing.Optional[VpnDomainNameAssignment], mtu_size: winsdk.system.UInt32, max_frame_size: winsdk.system.UInt32, reserved: winsdk.system.Boolean) -> None: ...
    def start_reconnecting_transport(self, transport: typing.Optional[winsdk.system.Object], context: typing.Optional[winsdk.system.Object]) -> None: ...
    def start_with_main_transport(self, assigned_client_i_pv4list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], assigned_client_i_pv6list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], vpn_interface_id: typing.Optional[VpnInterfaceId], assigned_routes: typing.Optional[VpnRouteAssignment], assigned_domain_name: typing.Optional[VpnDomainNameAssignment], mtu_size: winsdk.system.UInt32, max_frame_size: winsdk.system.UInt32, reserved: winsdk.system.Boolean, main_outer_tunnel_transport: typing.Optional[winsdk.system.Object]) -> None: ...
    @typing.overload
    def start_with_traffic_filter(self, assigned_client_ipv4_addresses: typing.Iterable[winsdk.windows.networking.HostName], assigned_client_ipv6_addresses: typing.Iterable[winsdk.windows.networking.HostName], vpninterface_id: typing.Optional[VpnInterfaceId], assigned_routes: typing.Optional[VpnRouteAssignment], assigned_namespace: typing.Optional[VpnDomainNameAssignment], mtu_size: winsdk.system.UInt32, max_frame_size: winsdk.system.UInt32, reserved: winsdk.system.Boolean, transports: typing.Iterable[winsdk.system.Object], assigned_traffic_filters: typing.Optional[VpnTrafficFilterAssignment]) -> None: ...
    @typing.overload
    def start_with_traffic_filter(self, assigned_client_ipv4_list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], assigned_client_ipv6_list: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName], vpn_interface_id: typing.Optional[VpnInterfaceId], assigned_routes: typing.Optional[VpnRouteAssignment], assigned_namespace: typing.Optional[VpnDomainNameAssignment], mtu_size: winsdk.system.UInt32, max_frame_size: winsdk.system.UInt32, reserved: winsdk.system.Boolean, main_outer_tunnel_transport: typing.Optional[winsdk.system.Object], optional_outer_tunnel_transport: typing.Optional[winsdk.system.Object], assigned_traffic_filters: typing.Optional[VpnTrafficFilterAssignment]) -> None: ...
    def stop(self) -> None: ...
    def terminate_connection(self, message: str) -> None: ...
    def add_activity_change(self, handler: winsdk.windows.foundation.TypedEventHandler[VpnChannel, VpnChannelActivityEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_activity_change(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_activity_state_change(self, handler: winsdk.windows.foundation.TypedEventHandler[VpnChannel, VpnChannelActivityStateChangedArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_activity_state_change(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class VpnChannelActivityEventArgs(winsdk.system.Object):
    type: VpnChannelActivityEventType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnChannelActivityEventArgs: ...

class VpnChannelActivityStateChangedArgs(winsdk.system.Object):
    activity_state: VpnChannelActivityEventType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnChannelActivityStateChangedArgs: ...

class VpnChannelConfiguration(winsdk.system.Object):
    custom_field: str
    server_host_name_list: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.HostName]]
    server_service_name: str
    server_uris: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.foundation.Uri]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnChannelConfiguration: ...

class VpnCredential(winsdk.system.Object):
    additional_pin: str
    certificate_credential: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    old_password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    passkey_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCredential: ...

class VpnCustomCheckBox(winsdk.system.Object):
    initial_check_state: winsdk.system.Boolean
    checked: winsdk.system.Boolean
    label: str
    compulsory: winsdk.system.Boolean
    bordered: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomCheckBox: ...
    def __new__(cls: typing.Type[VpnCustomCheckBox]) -> VpnCustomCheckBox:...

class VpnCustomComboBox(winsdk.system.Object):
    options_text: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    selected: winsdk.system.UInt32
    label: str
    compulsory: winsdk.system.Boolean
    bordered: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomComboBox: ...
    def __new__(cls: typing.Type[VpnCustomComboBox]) -> VpnCustomComboBox:...

class VpnCustomEditBox(winsdk.system.Object):
    no_echo: winsdk.system.Boolean
    default_text: str
    text: str
    label: str
    compulsory: winsdk.system.Boolean
    bordered: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomEditBox: ...
    def __new__(cls: typing.Type[VpnCustomEditBox]) -> VpnCustomEditBox:...

class VpnCustomErrorBox(winsdk.system.Object):
    label: str
    compulsory: winsdk.system.Boolean
    bordered: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomErrorBox: ...
    def __new__(cls: typing.Type[VpnCustomErrorBox]) -> VpnCustomErrorBox:...

class VpnCustomPromptBooleanInput(winsdk.system.Object):
    initial_value: winsdk.system.Boolean
    value: winsdk.system.Boolean
    emphasized: winsdk.system.Boolean
    display_name: str
    compulsory: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomPromptBooleanInput: ...
    def __new__(cls: typing.Type[VpnCustomPromptBooleanInput]) -> VpnCustomPromptBooleanInput:...

class VpnCustomPromptOptionSelector(winsdk.system.Object):
    emphasized: winsdk.system.Boolean
    display_name: str
    compulsory: winsdk.system.Boolean
    options: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    selected_index: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomPromptOptionSelector: ...
    def __new__(cls: typing.Type[VpnCustomPromptOptionSelector]) -> VpnCustomPromptOptionSelector:...

class VpnCustomPromptText(winsdk.system.Object):
    emphasized: winsdk.system.Boolean
    display_name: str
    compulsory: winsdk.system.Boolean
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomPromptText: ...
    def __new__(cls: typing.Type[VpnCustomPromptText]) -> VpnCustomPromptText:...

class VpnCustomPromptTextInput(winsdk.system.Object):
    emphasized: winsdk.system.Boolean
    display_name: str
    compulsory: winsdk.system.Boolean
    placeholder_text: str
    is_text_hidden: winsdk.system.Boolean
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomPromptTextInput: ...
    def __new__(cls: typing.Type[VpnCustomPromptTextInput]) -> VpnCustomPromptTextInput:...

class VpnCustomTextBox(winsdk.system.Object):
    label: str
    compulsory: winsdk.system.Boolean
    bordered: winsdk.system.Boolean
    display_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnCustomTextBox: ...
    def __new__(cls: typing.Type[VpnCustomTextBox]) -> VpnCustomTextBox:...

class VpnDomainNameAssignment(winsdk.system.Object):
    proxy_auto_configuration_uri: typing.Optional[winsdk.windows.foundation.Uri]
    domain_name_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnDomainNameInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnDomainNameAssignment: ...
    def __new__(cls: typing.Type[VpnDomainNameAssignment]) -> VpnDomainNameAssignment:...

class VpnDomainNameInfo(winsdk.system.Object):
    domain_name_type: VpnDomainNameType
    domain_name: typing.Optional[winsdk.windows.networking.HostName]
    dns_servers: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]]
    web_proxy_servers: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]]
    web_proxy_uris: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.foundation.Uri]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnDomainNameInfo: ...
    def __new__(cls: typing.Type[VpnDomainNameInfo], name: str, name_type: VpnDomainNameType, dns_server_list: typing.Iterable[winsdk.windows.networking.HostName], proxy_server_list: typing.Iterable[winsdk.windows.networking.HostName]) -> VpnDomainNameInfo:...

class VpnForegroundActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    activation_operation: typing.Optional[VpnForegroundActivationOperation]
    profile_name: str
    shared_context: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnForegroundActivatedEventArgs: ...

class VpnForegroundActivationOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnForegroundActivationOperation: ...
    def complete(self, result: typing.Optional[winsdk.windows.foundation.collections.ValueSet]) -> None: ...

class VpnInterfaceId(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnInterfaceId: ...
    def __new__(cls: typing.Type[VpnInterfaceId], address: winsdk.system.Array[winsdk.system.UInt8]) -> VpnInterfaceId:...
    def get_address_info(self) -> winsdk.system.Array[winsdk.system.UInt8]: ...

class VpnManagementAgent(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnManagementAgent: ...
    def __new__(cls: typing.Type[VpnManagementAgent]) -> VpnManagementAgent:...
    def add_profile_from_object_async(self, profile: typing.Optional[IVpnProfile]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def add_profile_from_xml_async(self, xml: str) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def connect_profile_async(self, profile: typing.Optional[IVpnProfile]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def connect_profile_with_password_credential_async(self, profile: typing.Optional[IVpnProfile], password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def delete_profile_async(self, profile: typing.Optional[IVpnProfile]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def disconnect_profile_async(self, profile: typing.Optional[IVpnProfile]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def get_profiles_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[IVpnProfile]]: ...
    def update_profile_from_object_async(self, profile: typing.Optional[IVpnProfile]) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...
    def update_profile_from_xml_async(self, xml: str) -> winsdk.windows.foundation.IAsyncOperation[VpnManagementErrorStatus]: ...

class VpnNamespaceAssignment(winsdk.system.Object):
    proxy_auto_config_uri: typing.Optional[winsdk.windows.foundation.Uri]
    namespace_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnNamespaceInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnNamespaceAssignment: ...
    def __new__(cls: typing.Type[VpnNamespaceAssignment]) -> VpnNamespaceAssignment:...

class VpnNamespaceInfo(winsdk.system.Object):
    web_proxy_servers: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]]
    namespace: str
    dns_servers: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnNamespaceInfo: ...
    def __new__(cls: typing.Type[VpnNamespaceInfo], name: str, dns_server_list: winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName], proxy_server_list: winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]) -> VpnNamespaceInfo:...

class VpnNativeProfile(winsdk.system.Object):
    user_authentication_method: VpnAuthenticationMethod
    tunnel_authentication_method: VpnAuthenticationMethod
    routing_policy_type: VpnRoutingPolicyType
    eap_configuration: str
    native_protocol_type: VpnNativeProtocolType
    servers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    require_vpn_client_app_u_i: winsdk.system.Boolean
    connection_status: VpnManagementConnectionStatus
    profile_name: str
    remember_credentials: winsdk.system.Boolean
    always_on: winsdk.system.Boolean
    routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    app_triggers: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnAppId]]
    traffic_filters: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnTrafficFilter]]
    domain_name_info_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnDomainNameInfo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnNativeProfile: ...
    def __new__(cls: typing.Type[VpnNativeProfile]) -> VpnNativeProfile:...

class VpnPacketBuffer(winsdk.system.Object):
    transport_affinity: winsdk.system.UInt32
    status: VpnPacketBufferStatus
    buffer: typing.Optional[winsdk.windows.storage.streams.Buffer]
    app_id: typing.Optional[VpnAppId]
    transport_context: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnPacketBuffer: ...
    def __new__(cls: typing.Type[VpnPacketBuffer], parent_buffer: typing.Optional[VpnPacketBuffer], offset: winsdk.system.UInt32, length: winsdk.system.UInt32) -> VpnPacketBuffer:...

class VpnPacketBufferList(winsdk.system.Object):
    status: VpnPacketBufferStatus
    size: winsdk.system.UInt32
    def __iter__(self) -> winsdk.windows.foundation.collections.IIterator[VpnPacketBuffer]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnPacketBufferList: ...
    def add_at_begin(self, next_vpn_packet_buffer: typing.Optional[VpnPacketBuffer]) -> None: ...
    def append(self, next_vpn_packet_buffer: typing.Optional[VpnPacketBuffer]) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[VpnPacketBuffer]]: ...
    def remove_at_begin(self) -> typing.Optional[VpnPacketBuffer]: ...
    def remove_at_end(self) -> typing.Optional[VpnPacketBuffer]: ...

class VpnPickedCredential(winsdk.system.Object):
    additional_pin: str
    old_password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    passkey_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnPickedCredential: ...

class VpnPlugInProfile(winsdk.system.Object):
    vpn_plugin_package_family_name: str
    custom_configuration: str
    server_uris: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.foundation.Uri]]
    require_vpn_client_app_u_i: winsdk.system.Boolean
    connection_status: VpnManagementConnectionStatus
    profile_name: str
    remember_credentials: winsdk.system.Boolean
    always_on: winsdk.system.Boolean
    app_triggers: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnAppId]]
    domain_name_info_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnDomainNameInfo]]
    routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    traffic_filters: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnTrafficFilter]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnPlugInProfile: ...
    def __new__(cls: typing.Type[VpnPlugInProfile]) -> VpnPlugInProfile:...

class VpnRoute(winsdk.system.Object):
    prefix_size: winsdk.system.UInt8
    address: typing.Optional[winsdk.windows.networking.HostName]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnRoute: ...
    def __new__(cls: typing.Type[VpnRoute], address: typing.Optional[winsdk.windows.networking.HostName], prefix_size: winsdk.system.UInt8) -> VpnRoute:...

class VpnRouteAssignment(winsdk.system.Object):
    ipv6_inclusion_routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    ipv6_exclusion_routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    ipv4_inclusion_routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    ipv4_exclusion_routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    exclude_local_subnets: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnRouteAssignment: ...
    def __new__(cls: typing.Type[VpnRouteAssignment]) -> VpnRouteAssignment:...

class VpnSystemHealth(winsdk.system.Object):
    statement_of_health: typing.Optional[winsdk.windows.storage.streams.Buffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnSystemHealth: ...

class VpnTrafficFilter(winsdk.system.Object):
    routing_policy_type: VpnRoutingPolicyType
    protocol: VpnIPProtocol
    app_id: typing.Optional[VpnAppId]
    app_claims: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    local_address_ranges: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    local_port_ranges: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    remote_address_ranges: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    remote_port_ranges: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnTrafficFilter: ...
    def __new__(cls: typing.Type[VpnTrafficFilter], app_id: typing.Optional[VpnAppId]) -> VpnTrafficFilter:...

class VpnTrafficFilterAssignment(winsdk.system.Object):
    allow_outbound: winsdk.system.Boolean
    allow_inbound: winsdk.system.Boolean
    traffic_filter_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnTrafficFilter]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VpnTrafficFilterAssignment: ...
    def __new__(cls: typing.Type[VpnTrafficFilterAssignment]) -> VpnTrafficFilterAssignment:...

class IVpnChannelStatics(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnChannelStatics: ...
    def process_event_async(self, third_party_plug_in: typing.Optional[winsdk.system.Object], event: typing.Optional[winsdk.system.Object]) -> None: ...

class IVpnCredential(winsdk.system.Object):
    additional_pin: str
    certificate_credential: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    old_password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    passkey_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnCredential: ...

class IVpnCustomPrompt(winsdk.system.Object):
    bordered: winsdk.system.Boolean
    compulsory: winsdk.system.Boolean
    label: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnCustomPrompt: ...

class IVpnCustomPromptElement(winsdk.system.Object):
    compulsory: winsdk.system.Boolean
    display_name: str
    emphasized: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnCustomPromptElement: ...

class IVpnDomainNameInfoFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnDomainNameInfoFactory: ...
    def create_vpn_domain_name_info(self, name: str, name_type: VpnDomainNameType, dns_server_list: typing.Iterable[winsdk.windows.networking.HostName], proxy_server_list: typing.Iterable[winsdk.windows.networking.HostName]) -> typing.Optional[VpnDomainNameInfo]: ...

class IVpnInterfaceIdFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnInterfaceIdFactory: ...
    def create_vpn_interface_id(self, address: winsdk.system.Array[winsdk.system.UInt8]) -> typing.Optional[VpnInterfaceId]: ...

class IVpnNamespaceInfoFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnNamespaceInfoFactory: ...
    def create_vpn_namespace_info(self, name: str, dns_server_list: winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName], proxy_server_list: winsdk.windows.foundation.collections.IVector[winsdk.windows.networking.HostName]) -> typing.Optional[VpnNamespaceInfo]: ...

class IVpnPacketBufferFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnPacketBufferFactory: ...
    def create_vpn_packet_buffer(self, parent_buffer: typing.Optional[VpnPacketBuffer], offset: winsdk.system.UInt32, length: winsdk.system.UInt32) -> typing.Optional[VpnPacketBuffer]: ...

class IVpnPlugIn(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnPlugIn: ...
    def connect(self, channel: typing.Optional[VpnChannel]) -> None: ...
    def decapsulate(self, channel: typing.Optional[VpnChannel], encap_buffer: typing.Optional[VpnPacketBuffer], decapsulated_packets: typing.Optional[VpnPacketBufferList], control_packets_to_send: typing.Optional[VpnPacketBufferList]) -> None: ...
    def disconnect(self, channel: typing.Optional[VpnChannel]) -> None: ...
    def encapsulate(self, channel: typing.Optional[VpnChannel], packets: typing.Optional[VpnPacketBufferList], encapulated_packets: typing.Optional[VpnPacketBufferList]) -> None: ...
    def get_keep_alive_payload(self, channel: typing.Optional[VpnChannel]) -> typing.Optional[VpnPacketBuffer]: ...

class IVpnProfile(winsdk.system.Object):
    always_on: winsdk.system.Boolean
    app_triggers: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnAppId]]
    domain_name_info_list: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnDomainNameInfo]]
    profile_name: str
    remember_credentials: winsdk.system.Boolean
    routes: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnRoute]]
    traffic_filters: typing.Optional[winsdk.windows.foundation.collections.IVector[VpnTrafficFilter]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnProfile: ...

class IVpnRouteFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVpnRouteFactory: ...
    def create_vpn_route(self, address: typing.Optional[winsdk.windows.networking.HostName], prefix_size: winsdk.system.UInt8) -> typing.Optional[VpnRoute]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Management.Core")

try:
    import winsdk.windows.storage
except ImportError:
    pass


ApplicationDataManager = _ns_module.ApplicationDataManager



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Services.Maps.OfflineMaps")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class OfflineMapPackageQueryStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    NETWORK_FAILURE = 3

class OfflineMapPackageStartDownloadStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    DENIED_WITHOUT_CAPABILITY = 3

class OfflineMapPackageStatus(enum.IntEnum):
    NOT_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    DELETING = 3

_ns_module._register_OfflineMapPackageQueryStatus(OfflineMapPackageQueryStatus)
_ns_module._register_OfflineMapPackageStartDownloadStatus(OfflineMapPackageStartDownloadStatus)
_ns_module._register_OfflineMapPackageStatus(OfflineMapPackageStatus)

OfflineMapPackage = _ns_module.OfflineMapPackage
OfflineMapPackageQueryResult = _ns_module.OfflineMapPackageQueryResult
OfflineMapPackageStartDownloadResult = _ns_module.OfflineMapPackageStartDownloadResult



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.WebUI.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class WebUICommandBarClosedDisplayMode(enum.IntEnum):
    DEFAULT = 0
    MINIMAL = 1
    COMPACT = 2

_ns_module._register_WebUICommandBarClosedDisplayMode(WebUICommandBarClosedDisplayMode)

WebUICommandBar = _ns_module.WebUICommandBar
WebUICommandBarBitmapIcon = _ns_module.WebUICommandBarBitmapIcon
WebUICommandBarConfirmationButton = _ns_module.WebUICommandBarConfirmationButton
WebUICommandBarIconButton = _ns_module.WebUICommandBarIconButton
WebUICommandBarItemInvokedEventArgs = _ns_module.WebUICommandBarItemInvokedEventArgs
WebUICommandBarSizeChangedEventArgs = _ns_module.WebUICommandBarSizeChangedEventArgs
WebUICommandBarSymbolIcon = _ns_module.WebUICommandBarSymbolIcon
IWebUICommandBarElement = _ns_module.IWebUICommandBarElement
IWebUICommandBarIcon = _ns_module.IWebUICommandBarIcon



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class MdmAlertDataType(enum.IntEnum):
    STRING = 0
    BASE64 = 1
    BOOLEAN = 2
    INTEGER = 3

class MdmAlertMark(enum.IntEnum):
    NONE = 0
    FATAL = 1
    CRITICAL = 2
    WARNING = 3
    INFORMATIONAL = 4

class MdmSessionState(enum.IntEnum):
    NOT_STARTED = 0
    STARTING = 1
    CONNECTING = 2
    COMMUNICATING = 3
    ALERT_STATUS_AVAILABLE = 4
    RETRYING = 5
    COMPLETED = 6

Self = typing.TypeVar('Self')

class MdmAlert(winsdk.system.Object):
    type: str
    target: str
    source: str
    mark: MdmAlertMark
    format: MdmAlertDataType
    data: str
    status: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmAlert: ...
    def __new__(cls: typing.Type[MdmAlert]) -> MdmAlert:...

class MdmSession(winsdk.system.Object):
    alerts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[MdmAlert]]
    extended_error: winsdk.windows.foundation.HResult
    id: str
    state: MdmSessionState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmSession: ...
    def attach_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete(self) -> None: ...
    @typing.overload
    def start_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def start_async(self, alerts: typing.Iterable[MdmAlert]) -> winsdk.windows.foundation.IAsyncAction: ...

class MdmSessionManager(winsdk.system.Object):
    session_ids: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MdmSessionManager: ...
    @staticmethod
    def delete_session_by_id(session_id: str) -> None: ...
    @staticmethod
    def get_session_by_id(session_id: str) -> typing.Optional[MdmSession]: ...
    @staticmethod
    def try_create_session() -> typing.Optional[MdmSession]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Resources.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class ResourceCandidateKind(enum.IntEnum):
    STRING = 0
    FILE = 1
    EMBEDDED_DATA = 2

class ResourceQualifierPersistence(enum.IntEnum):
    NONE = 0
    LOCAL_MACHINE = 1

_ns_module._register_ResourceCandidateKind(ResourceCandidateKind)
_ns_module._register_ResourceQualifierPersistence(ResourceQualifierPersistence)

ResourceLayoutInfo = _ns_module.ResourceLayoutInfo
NamedResource = _ns_module.NamedResource
ResourceCandidate = _ns_module.ResourceCandidate
ResourceCandidateVectorView = _ns_module.ResourceCandidateVectorView
ResourceContext = _ns_module.ResourceContext
ResourceContextLanguagesVectorView = _ns_module.ResourceContextLanguagesVectorView
ResourceManager = _ns_module.ResourceManager
ResourceMap = _ns_module.ResourceMap
ResourceMapIterator = _ns_module.ResourceMapIterator
ResourceMapMapView = _ns_module.ResourceMapMapView
ResourceMapMapViewIterator = _ns_module.ResourceMapMapViewIterator
ResourceQualifier = _ns_module.ResourceQualifier
ResourceQualifierMapView = _ns_module.ResourceQualifierMapView
ResourceQualifierObservableMap = _ns_module.ResourceQualifierObservableMap
ResourceQualifierVectorView = _ns_module.ResourceQualifierVectorView



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Calls")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class CellularDtmfMode(enum.IntEnum):
    CONTINUOUS = 0
    BURST = 1

class DtmfKey(enum.IntEnum):
    D0 = 0
    D1 = 1
    D2 = 2
    D3 = 3
    D4 = 4
    D5 = 5
    D6 = 6
    D7 = 7
    D8 = 8
    D9 = 9
    STAR = 10
    POUND = 11

class DtmfToneAudioPlayback(enum.IntEnum):
    PLAY = 0
    DO_NOT_PLAY = 1

class PhoneAudioRoutingEndpoint(enum.IntEnum):
    DEFAULT = 0
    BLUETOOTH = 1
    SPEAKERPHONE = 2

class PhoneCallAudioDevice(enum.IntEnum):
    UNKNOWN = 0
    LOCAL_DEVICE = 1
    REMOTE_DEVICE = 2

class PhoneCallDirection(enum.IntEnum):
    UNKNOWN = 0
    INCOMING = 1
    OUTGOING = 2

class PhoneCallHistoryEntryMedia(enum.IntEnum):
    AUDIO = 0
    VIDEO = 1

class PhoneCallHistoryEntryOtherAppReadAccess(enum.IntEnum):
    FULL = 0
    SYSTEM_ONLY = 1

class PhoneCallHistoryEntryQueryDesiredMedia(enum.IntFlag):
    NONE = 0
    AUDIO = 0x1
    VIDEO = 0x2
    ALL = 0xffffffff

class PhoneCallHistoryEntryRawAddressKind(enum.IntEnum):
    PHONE_NUMBER = 0
    CUSTOM = 1

class PhoneCallHistorySourceIdKind(enum.IntEnum):
    CELLULAR_PHONE_LINE_ID = 0
    PACKAGE_FAMILY_NAME = 1

class PhoneCallHistoryStoreAccessType(enum.IntEnum):
    APP_ENTRIES_READ_WRITE = 0
    ALL_ENTRIES_LIMITED_READ_WRITE = 1
    ALL_ENTRIES_READ_WRITE = 2

class PhoneCallMedia(enum.IntEnum):
    AUDIO = 0
    AUDIO_AND_VIDEO = 1
    AUDIO_AND_REAL_TIME_TEXT = 2

class PhoneCallOperationStatus(enum.IntEnum):
    SUCCEEDED = 0
    OTHER_FAILURE = 1
    TIMED_OUT = 2
    CONNECTION_LOST = 3
    INVALID_CALL_STATE = 4

class PhoneCallStatus(enum.IntEnum):
    LOST = 0
    INCOMING = 1
    DIALING = 2
    TALKING = 3
    HELD = 4
    ENDED = 5

class PhoneLineNetworkOperatorDisplayTextLocation(enum.IntEnum):
    DEFAULT = 0
    TILE = 1
    DIALER = 2
    IN_CALL_U_I = 3

class PhoneLineOperationStatus(enum.IntEnum):
    SUCCEEDED = 0
    OTHER_FAILURE = 1
    TIMED_OUT = 2
    CONNECTION_LOST = 3
    INVALID_CALL_STATE = 4

class PhoneLineTransport(enum.IntEnum):
    CELLULAR = 0
    VOIP_APP = 1
    BLUETOOTH = 2

class PhoneLineWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPED = 3

class PhoneNetworkState(enum.IntEnum):
    UNKNOWN = 0
    NO_SIGNAL = 1
    DEREGISTERED = 2
    DENIED = 3
    SEARCHING = 4
    HOME = 5
    ROAMING_INTERNATIONAL = 6
    ROAMING_DOMESTIC = 7

class PhoneSimState(enum.IntEnum):
    UNKNOWN = 0
    PIN_NOT_REQUIRED = 1
    PIN_UNLOCKED = 2
    PIN_LOCKED = 3
    PUK_LOCKED = 4
    NOT_INSERTED = 5
    INVALID = 6
    DISABLED = 7

class PhoneVoicemailType(enum.IntEnum):
    NONE = 0
    TRADITIONAL = 1
    VISUAL = 2

class TransportDeviceAudioRoutingStatus(enum.IntEnum):
    UNKNOWN = 0
    CAN_ROUTE_TO_LOCAL_DEVICE = 1
    CANNOT_ROUTE_TO_LOCAL_DEVICE = 2

class VoipPhoneCallMedia(enum.IntFlag):
    NONE = 0
    AUDIO = 0x1
    VIDEO = 0x2

class VoipPhoneCallRejectReason(enum.IntEnum):
    USER_IGNORED = 0
    TIMED_OUT = 1
    OTHER_INCOMING_CALL = 2
    EMERGENCY_CALL_EXISTS = 3
    INVALID_CALL_STATE = 4

class VoipPhoneCallResourceReservationStatus(enum.IntEnum):
    SUCCESS = 0
    RESOURCES_NOT_AVAILABLE = 1

class VoipPhoneCallState(enum.IntEnum):
    ENDED = 0
    HELD = 1
    ACTIVE = 2
    INCOMING = 3
    OUTGOING = 4

_ns_module._register_CellularDtmfMode(CellularDtmfMode)
_ns_module._register_DtmfKey(DtmfKey)
_ns_module._register_DtmfToneAudioPlayback(DtmfToneAudioPlayback)
_ns_module._register_PhoneAudioRoutingEndpoint(PhoneAudioRoutingEndpoint)
_ns_module._register_PhoneCallAudioDevice(PhoneCallAudioDevice)
_ns_module._register_PhoneCallDirection(PhoneCallDirection)
_ns_module._register_PhoneCallHistoryEntryMedia(PhoneCallHistoryEntryMedia)
_ns_module._register_PhoneCallHistoryEntryOtherAppReadAccess(PhoneCallHistoryEntryOtherAppReadAccess)
_ns_module._register_PhoneCallHistoryEntryQueryDesiredMedia(PhoneCallHistoryEntryQueryDesiredMedia)
_ns_module._register_PhoneCallHistoryEntryRawAddressKind(PhoneCallHistoryEntryRawAddressKind)
_ns_module._register_PhoneCallHistorySourceIdKind(PhoneCallHistorySourceIdKind)
_ns_module._register_PhoneCallHistoryStoreAccessType(PhoneCallHistoryStoreAccessType)
_ns_module._register_PhoneCallMedia(PhoneCallMedia)
_ns_module._register_PhoneCallOperationStatus(PhoneCallOperationStatus)
_ns_module._register_PhoneCallStatus(PhoneCallStatus)
_ns_module._register_PhoneLineNetworkOperatorDisplayTextLocation(PhoneLineNetworkOperatorDisplayTextLocation)
_ns_module._register_PhoneLineOperationStatus(PhoneLineOperationStatus)
_ns_module._register_PhoneLineTransport(PhoneLineTransport)
_ns_module._register_PhoneLineWatcherStatus(PhoneLineWatcherStatus)
_ns_module._register_PhoneNetworkState(PhoneNetworkState)
_ns_module._register_PhoneSimState(PhoneSimState)
_ns_module._register_PhoneVoicemailType(PhoneVoicemailType)
_ns_module._register_TransportDeviceAudioRoutingStatus(TransportDeviceAudioRoutingStatus)
_ns_module._register_VoipPhoneCallMedia(VoipPhoneCallMedia)
_ns_module._register_VoipPhoneCallRejectReason(VoipPhoneCallRejectReason)
_ns_module._register_VoipPhoneCallResourceReservationStatus(VoipPhoneCallResourceReservationStatus)
_ns_module._register_VoipPhoneCallState(VoipPhoneCallState)

CallAnswerEventArgs = _ns_module.CallAnswerEventArgs
CallRejectEventArgs = _ns_module.CallRejectEventArgs
CallStateChangeEventArgs = _ns_module.CallStateChangeEventArgs
LockScreenCallEndCallDeferral = _ns_module.LockScreenCallEndCallDeferral
LockScreenCallEndRequestedEventArgs = _ns_module.LockScreenCallEndRequestedEventArgs
LockScreenCallUI = _ns_module.LockScreenCallUI
MuteChangeEventArgs = _ns_module.MuteChangeEventArgs
PhoneCall = _ns_module.PhoneCall
PhoneCallBlocking = _ns_module.PhoneCallBlocking
PhoneCallHistoryEntry = _ns_module.PhoneCallHistoryEntry
PhoneCallHistoryEntryAddress = _ns_module.PhoneCallHistoryEntryAddress
PhoneCallHistoryEntryQueryOptions = _ns_module.PhoneCallHistoryEntryQueryOptions
PhoneCallHistoryEntryReader = _ns_module.PhoneCallHistoryEntryReader
PhoneCallHistoryManager = _ns_module.PhoneCallHistoryManager
PhoneCallHistoryManagerForUser = _ns_module.PhoneCallHistoryManagerForUser
PhoneCallHistoryStore = _ns_module.PhoneCallHistoryStore
PhoneCallInfo = _ns_module.PhoneCallInfo
PhoneCallManager = _ns_module.PhoneCallManager
PhoneCallStore = _ns_module.PhoneCallStore
PhoneCallVideoCapabilities = _ns_module.PhoneCallVideoCapabilities
PhoneCallVideoCapabilitiesManager = _ns_module.PhoneCallVideoCapabilitiesManager
PhoneCallsResult = _ns_module.PhoneCallsResult
PhoneDialOptions = _ns_module.PhoneDialOptions
PhoneLine = _ns_module.PhoneLine
PhoneLineCellularDetails = _ns_module.PhoneLineCellularDetails
PhoneLineConfiguration = _ns_module.PhoneLineConfiguration
PhoneLineDialResult = _ns_module.PhoneLineDialResult
PhoneLineTransportDevice = _ns_module.PhoneLineTransportDevice
PhoneLineWatcher = _ns_module.PhoneLineWatcher
PhoneLineWatcherEventArgs = _ns_module.PhoneLineWatcherEventArgs
PhoneVoicemail = _ns_module.PhoneVoicemail
VoipCallCoordinator = _ns_module.VoipCallCoordinator
VoipPhoneCall = _ns_module.VoipPhoneCall



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.SerialCommunication")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class SerialError(enum.IntEnum):
    FRAME = 0
    BUFFER_OVERRUN = 1
    RECEIVE_FULL = 2
    RECEIVE_PARITY = 3
    TRANSMIT_FULL = 4

class SerialHandshake(enum.IntEnum):
    NONE = 0
    REQUEST_TO_SEND = 1
    X_ON_X_OFF = 2
    REQUEST_TO_SEND_X_ON_X_OFF = 3

class SerialParity(enum.IntEnum):
    NONE = 0
    ODD = 1
    EVEN = 2
    MARK = 3
    SPACE = 4

class SerialPinChange(enum.IntEnum):
    BREAK_SIGNAL = 0
    CARRIER_DETECT = 1
    CLEAR_TO_SEND = 2
    DATA_SET_READY = 3
    RING_INDICATOR = 4

class SerialStopBitCount(enum.IntEnum):
    ONE = 0
    ONE_POINT_FIVE = 1
    TWO = 2

_ns_module._register_SerialError(SerialError)
_ns_module._register_SerialHandshake(SerialHandshake)
_ns_module._register_SerialParity(SerialParity)
_ns_module._register_SerialPinChange(SerialPinChange)
_ns_module._register_SerialStopBitCount(SerialStopBitCount)

ErrorReceivedEventArgs = _ns_module.ErrorReceivedEventArgs
PinChangedEventArgs = _ns_module.PinChangedEventArgs
SerialDevice = _ns_module.SerialDevice



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Foundation.Collections")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class CollectionChange(enum.IntEnum):
    RESET = 0
    ITEM_INSERTED = 1
    ITEM_REMOVED = 2
    ITEM_CHANGED = 3

_ns_module._register_CollectionChange(CollectionChange)

PropertySet = _ns_module.PropertySet
StringMap = _ns_module.StringMap
ValueSet = _ns_module.ValueSet
IIterable = _ns_module.IIterable
IIterator = _ns_module.IIterator
IKeyValuePair = _ns_module.IKeyValuePair
IMapChangedEventArgs = _ns_module.IMapChangedEventArgs
IMapView = _ns_module.IMapView
IMap = _ns_module.IMap
IObservableMap = _ns_module.IObservableMap
IObservableVector = _ns_module.IObservableVector
IPropertySet = _ns_module.IPropertySet
IVectorChangedEventArgs = _ns_module.IVectorChangedEventArgs
IVectorView = _ns_module.IVectorView
IVector = _ns_module.IVector



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.Update")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class SystemUpdateAttentionRequiredReason(enum.IntEnum):
    NONE = 0
    NETWORK_REQUIRED = 1
    INSUFFICIENT_DISK_SPACE = 2
    INSUFFICIENT_BATTERY = 3
    UPDATE_BLOCKED = 4

class SystemUpdateItemState(enum.IntEnum):
    NOT_STARTED = 0
    INITIALIZING = 1
    PREPARING = 2
    CALCULATING = 3
    DOWNLOADING = 4
    INSTALLING = 5
    COMPLETED = 6
    REBOOT_REQUIRED = 7
    ERROR = 8

class SystemUpdateManagerState(enum.IntEnum):
    IDLE = 0
    DETECTING = 1
    READY_TO_DOWNLOAD = 2
    DOWNLOADING = 3
    READY_TO_INSTALL = 4
    INSTALLING = 5
    REBOOT_REQUIRED = 6
    READY_TO_FINALIZE = 7
    FINALIZING = 8
    COMPLETED = 9
    ATTENTION_REQUIRED = 10
    ERROR = 11

class SystemUpdateStartInstallAction(enum.IntEnum):
    UP_TO_REBOOT = 0
    ALLOW_REBOOT = 1

_ns_module._register_SystemUpdateAttentionRequiredReason(SystemUpdateAttentionRequiredReason)
_ns_module._register_SystemUpdateItemState(SystemUpdateItemState)
_ns_module._register_SystemUpdateManagerState(SystemUpdateManagerState)
_ns_module._register_SystemUpdateStartInstallAction(SystemUpdateStartInstallAction)

SystemUpdateItem = _ns_module.SystemUpdateItem
SystemUpdateLastErrorInfo = _ns_module.SystemUpdateLastErrorInfo
SystemUpdateManager = _ns_module.SystemUpdateManager



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.storage.streams

class GameServiceGameOutcome(enum.IntEnum):
    NONE = 0
    WIN = 1
    LOSS = 2
    TIE = 3

class GameServiceScoreKind(enum.IntEnum):
    NUMBER = 0
    TIME = 1

Self = typing.TypeVar('Self')

class GameService(winsdk.system.Object):
    service_uri: typing.ClassVar[typing.Optional[winsdk.windows.foundation.Uri]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameService: ...
    @staticmethod
    def get_authentication_status() -> winsdk.system.UInt32: ...
    @staticmethod
    def get_gamer_profile_async() -> winsdk.windows.foundation.IAsyncOperation[GameServicePropertyCollection]: ...
    @staticmethod
    def get_installed_game_items_async() -> winsdk.windows.foundation.IAsyncOperation[GameServicePropertyCollection]: ...
    @staticmethod
    def get_partner_token_async(audience_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_privileges_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def grant_achievement(achievement_id: winsdk.system.UInt32) -> None: ...
    @staticmethod
    def grant_avatar_award(avatar_award_id: winsdk.system.UInt32) -> None: ...
    @staticmethod
    def notify_partner_token_expired(audience_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    @staticmethod
    def post_result(game_variant: winsdk.system.UInt32, score_kind: GameServiceScoreKind, score_value: winsdk.system.Int64, game_outcome: GameServiceGameOutcome, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> None: ...

class GameServicePropertyCollection(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GameServicePropertyCollection: ...
    def get_property_async(self, property_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Object]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class CollectionChange(enum.IntEnum):
    RESET = 0
    ITEM_INSERTED = 1
    ITEM_REMOVED = 2
    ITEM_CHANGED = 3

Self = typing.TypeVar('Self')
K = typing.TypeVar('K')
T = typing.TypeVar('T')
V = typing.TypeVar('V')

class PropertySet(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PropertySet: ...
    def __new__(cls: typing.Type[PropertySet]) -> PropertySet:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: str) -> None: ...
    def add_map_changed(self, vhnd: MapChangedEventHandler[str, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StringMap(winsdk.system.Object, typing.MutableMapping[str, str]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: str) -> None: ...
    def __getitem__(self, key: str) -> str: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StringMap: ...
    def __new__(cls: typing.Type[StringMap]) -> StringMap:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[str, str]]]: ...
    def get_view(self) -> typing.Optional[IMapView[str, str]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: str) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> str: ...
    def remove(self, key: str) -> None: ...
    def add_map_changed(self, vhnd: MapChangedEventHandler[str, str]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ValueSet(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ValueSet: ...
    def __new__(cls: typing.Type[ValueSet]) -> ValueSet:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: str) -> None: ...
    def add_map_changed(self, vhnd: MapChangedEventHandler[str, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IIterable(winsdk.system.Object, typing.Generic[T]):
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __iter__(self) -> IIterator[T]: ...
    def first(self) -> typing.Optional[IIterator[T]]: ...

class IIterator(winsdk.system.Object, typing.Generic[T]):
    current: typing.Optional[T]
    has_current: winsdk.system.Boolean
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __iter__(self: Self) -> Self: ...
    def __next__(self) -> T: ...
    def get_many(self, items: winsdk.system.Array[T]) -> winsdk.system.UInt32: ...
    def move_next(self) -> winsdk.system.Boolean: ...

class IKeyValuePair(winsdk.system.Object, typing.Generic[K, V]):
    key: typing.Optional[K]
    value: typing.Optional[V]
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...

class IMapChangedEventArgs(winsdk.system.Object, typing.Generic[K]):
    collection_change: CollectionChange
    key: typing.Optional[K]
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...

class IMapView(winsdk.system.Object, typing.Mapping[K, V], typing.Generic[K, V]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[K]: ...
    def __contains__(self, key: object) -> bool:...
    def __getitem__(self, key: K) -> V: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[K, V]]]: ...
    def has_key(self, key: typing.Optional[K]) -> winsdk.system.Boolean: ...
    def lookup(self, key: typing.Optional[K]) -> typing.Optional[V]: ...
    def split(self) -> typing.Tuple[typing.Optional[IMapView[K, V]], typing.Optional[IMapView[K, V]]]: ...

class IMap(winsdk.system.Object, typing.MutableMapping[K, V], typing.Generic[K, V]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[K]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: K, value: V) -> None: ...
    def __getitem__(self, key: K) -> V: ...
    def __delitem__(self, key: K) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[K, V]]]: ...
    def get_view(self) -> typing.Optional[IMapView[K, V]]: ...
    def has_key(self, key: typing.Optional[K]) -> winsdk.system.Boolean: ...
    def insert(self, key: typing.Optional[K], value: typing.Optional[V]) -> winsdk.system.Boolean: ...
    def lookup(self, key: typing.Optional[K]) -> typing.Optional[V]: ...
    def remove(self, key: typing.Optional[K]) -> None: ...

class IObservableMap(winsdk.system.Object, typing.MutableMapping[K, V], typing.Generic[K, V]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[K]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: K, value: V) -> None: ...
    def __getitem__(self, key: K) -> V: ...
    def __delitem__(self, key: K) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[K, V]]]: ...
    def get_view(self) -> typing.Optional[IMapView[K, V]]: ...
    def has_key(self, key: typing.Optional[K]) -> winsdk.system.Boolean: ...
    def insert(self, key: typing.Optional[K], value: typing.Optional[V]) -> winsdk.system.Boolean: ...
    def lookup(self, key: typing.Optional[K]) -> typing.Optional[V]: ...
    def remove(self, key: typing.Optional[K]) -> None: ...
    def add_map_changed(self, vhnd: MapChangedEventHandler[K, V]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IObservableVector(winsdk.system.Object, typing.MutableSequence[T], typing.Generic[T]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> T: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[T]: ...
    def insert(self, index: int, value: T) -> None: ...
    @typing.overload
    def __delitem__(self, index: int) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    @typing.overload
    def __setitem__(self, index: int, value: T) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[T]) -> None: ...
    def append(self, value: typing.Optional[T]) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[T]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[T]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[T]) -> winsdk.system.UInt32: ...
    def get_view(self) -> typing.Optional[IVectorView[T]]: ...
    def index_of(self, value: typing.Optional[T]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def insert_at(self, index: winsdk.system.UInt32, value: typing.Optional[T]) -> None: ...
    def remove_at(self, index: winsdk.system.UInt32) -> None: ...
    def remove_at_end(self) -> None: ...
    def replace_all(self, items: winsdk.system.Array[T]) -> None: ...
    def set_at(self, index: winsdk.system.UInt32, value: typing.Optional[T]) -> None: ...
    def add_vector_changed(self, vhnd: VectorChangedEventHandler[T]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_vector_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IPropertySet(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPropertySet: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: typing.Optional[str]) -> winsdk.system.Boolean: ...
    def insert(self, key: typing.Optional[str], value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: typing.Optional[str]) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: typing.Optional[str]) -> None: ...
    def add_map_changed(self, vhnd: MapChangedEventHandler[str, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IVectorChangedEventArgs(winsdk.system.Object):
    collection_change: CollectionChange
    index: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVectorChangedEventArgs: ...

class IVectorView(winsdk.system.Object, typing.Sequence[T], typing.Generic[T]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> T: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[T]: ...
    def first(self) -> typing.Optional[IIterator[T]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[T]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[T]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[T]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...

class IVector(winsdk.system.Object, typing.MutableSequence[T], typing.Generic[T]):
    size: winsdk.system.UInt32
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> T: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[T]: ...
    def insert(self, index: int, value: T) -> None: ...
    @typing.overload
    def __delitem__(self, index: int) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    @typing.overload
    def __setitem__(self, index: int, value: T) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[T]) -> None: ...
    def append(self, value: typing.Optional[T]) -> None: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[IIterator[T]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[T]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[T]) -> winsdk.system.UInt32: ...
    def get_view(self) -> typing.Optional[IVectorView[T]]: ...
    def index_of(self, value: typing.Optional[T]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def insert_at(self, index: winsdk.system.UInt32, value: typing.Optional[T]) -> None: ...
    def remove_at(self, index: winsdk.system.UInt32) -> None: ...
    def remove_at_end(self) -> None: ...
    def replace_all(self, items: winsdk.system.Array[T]) -> None: ...
    def set_at(self, index: winsdk.system.UInt32, value: typing.Optional[T]) -> None: ...

MapChangedEventHandler = typing.Callable[[IObservableMap[K, V], IMapChangedEventArgs[K]], None]

VectorChangedEventHandler = typing.Callable[[IObservableVector[T], typing.Optional[IVectorChangedEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Bluetooth.GenericAttributeProfile")

try:
    import winsdk.windows.devices.bluetooth
except ImportError:
    pass

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class GattCharacteristicProperties(enum.IntFlag):
    NONE = 0
    BROADCAST = 0x1
    READ = 0x2
    WRITE_WITHOUT_RESPONSE = 0x4
    WRITE = 0x8
    NOTIFY = 0x10
    INDICATE = 0x20
    AUTHENTICATED_SIGNED_WRITES = 0x40
    EXTENDED_PROPERTIES = 0x80
    RELIABLE_WRITES = 0x100
    WRITABLE_AUXILIARIES = 0x200

class GattClientCharacteristicConfigurationDescriptorValue(enum.IntEnum):
    NONE = 0
    NOTIFY = 1
    INDICATE = 2

class GattCommunicationStatus(enum.IntEnum):
    SUCCESS = 0
    UNREACHABLE = 1
    PROTOCOL_ERROR = 2
    ACCESS_DENIED = 3

class GattOpenStatus(enum.IntEnum):
    UNSPECIFIED = 0
    SUCCESS = 1
    ALREADY_OPENED = 2
    NOT_FOUND = 3
    SHARING_VIOLATION = 4
    ACCESS_DENIED = 5

class GattProtectionLevel(enum.IntEnum):
    PLAIN = 0
    AUTHENTICATION_REQUIRED = 1
    ENCRYPTION_REQUIRED = 2
    ENCRYPTION_AND_AUTHENTICATION_REQUIRED = 3

class GattRequestState(enum.IntEnum):
    PENDING = 0
    COMPLETED = 1
    CANCELED = 2

class GattServiceProviderAdvertisementStatus(enum.IntEnum):
    CREATED = 0
    STOPPED = 1
    STARTED = 2
    ABORTED = 3
    STARTED_WITHOUT_ALL_ADVERTISEMENT_DATA = 4

class GattSessionStatus(enum.IntEnum):
    CLOSED = 0
    ACTIVE = 1

class GattSharingMode(enum.IntEnum):
    UNSPECIFIED = 0
    EXCLUSIVE = 1
    SHARED_READ_ONLY = 2
    SHARED_READ_AND_WRITE = 3

class GattWriteOption(enum.IntEnum):
    WRITE_WITH_RESPONSE = 0
    WRITE_WITHOUT_RESPONSE = 1

_ns_module._register_GattCharacteristicProperties(GattCharacteristicProperties)
_ns_module._register_GattClientCharacteristicConfigurationDescriptorValue(GattClientCharacteristicConfigurationDescriptorValue)
_ns_module._register_GattCommunicationStatus(GattCommunicationStatus)
_ns_module._register_GattOpenStatus(GattOpenStatus)
_ns_module._register_GattProtectionLevel(GattProtectionLevel)
_ns_module._register_GattRequestState(GattRequestState)
_ns_module._register_GattServiceProviderAdvertisementStatus(GattServiceProviderAdvertisementStatus)
_ns_module._register_GattSessionStatus(GattSessionStatus)
_ns_module._register_GattSharingMode(GattSharingMode)
_ns_module._register_GattWriteOption(GattWriteOption)

GattCharacteristic = _ns_module.GattCharacteristic
GattCharacteristicUuids = _ns_module.GattCharacteristicUuids
GattCharacteristicsResult = _ns_module.GattCharacteristicsResult
GattClientNotificationResult = _ns_module.GattClientNotificationResult
GattDescriptor = _ns_module.GattDescriptor
GattDescriptorUuids = _ns_module.GattDescriptorUuids
GattDescriptorsResult = _ns_module.GattDescriptorsResult
GattDeviceService = _ns_module.GattDeviceService
GattDeviceServicesResult = _ns_module.GattDeviceServicesResult
GattLocalCharacteristic = _ns_module.GattLocalCharacteristic
GattLocalCharacteristicParameters = _ns_module.GattLocalCharacteristicParameters
GattLocalCharacteristicResult = _ns_module.GattLocalCharacteristicResult
GattLocalDescriptor = _ns_module.GattLocalDescriptor
GattLocalDescriptorParameters = _ns_module.GattLocalDescriptorParameters
GattLocalDescriptorResult = _ns_module.GattLocalDescriptorResult
GattLocalService = _ns_module.GattLocalService
GattPresentationFormat = _ns_module.GattPresentationFormat
GattPresentationFormatTypes = _ns_module.GattPresentationFormatTypes
GattProtocolError = _ns_module.GattProtocolError
GattReadClientCharacteristicConfigurationDescriptorResult = _ns_module.GattReadClientCharacteristicConfigurationDescriptorResult
GattReadRequest = _ns_module.GattReadRequest
GattReadRequestedEventArgs = _ns_module.GattReadRequestedEventArgs
GattReadResult = _ns_module.GattReadResult
GattReliableWriteTransaction = _ns_module.GattReliableWriteTransaction
GattRequestStateChangedEventArgs = _ns_module.GattRequestStateChangedEventArgs
GattServiceProvider = _ns_module.GattServiceProvider
GattServiceProviderAdvertisementStatusChangedEventArgs = _ns_module.GattServiceProviderAdvertisementStatusChangedEventArgs
GattServiceProviderAdvertisingParameters = _ns_module.GattServiceProviderAdvertisingParameters
GattServiceProviderResult = _ns_module.GattServiceProviderResult
GattServiceUuids = _ns_module.GattServiceUuids
GattSession = _ns_module.GattSession
GattSessionStatusChangedEventArgs = _ns_module.GattSessionStatusChangedEventArgs
GattSubscribedClient = _ns_module.GattSubscribedClient
GattValueChangedEventArgs = _ns_module.GattValueChangedEventArgs
GattWriteRequest = _ns_module.GattWriteRequest
GattWriteRequestedEventArgs = _ns_module.GattWriteRequestedEventArgs
GattWriteResult = _ns_module.GattWriteResult



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.activation
import winsdk.windows.devices.printers
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.printing.printticket
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.system

class PdlConversionHostBasedProcessingOperations(enum.IntFlag):
    NONE = 0
    PAGE_ROTATION = 0x1
    PAGE_ORDERING = 0x2
    COPIES = 0x4
    BLANK_PAGE_INSERTION = 0x8
    ALL = 0xffffffff

class PrintWorkflowAttributesMergePolicy(enum.IntEnum):
    MERGE_PREFER_PRINT_TICKET_ON_CONFLICT = 0
    MERGE_PREFER_PSA_ON_CONFLICT = 1
    DO_NOT_MERGE_WITH_PRINT_TICKET = 2

class PrintWorkflowJobAbortReason(enum.IntEnum):
    JOB_FAILED = 0
    USER_CANCELED = 1

class PrintWorkflowPdlConversionType(enum.IntEnum):
    XPS_TO_PDF = 0
    XPS_TO_PWGR = 1
    XPS_TO_PCLM = 2

class PrintWorkflowPrinterJobStatus(enum.IntEnum):
    ERROR = 0
    ABORTED = 1
    IN_PROGRESS = 2
    COMPLETED = 3

class PrintWorkflowSessionStatus(enum.IntEnum):
    STARTED = 0
    COMPLETED = 1
    ABORTED = 2
    CLOSED = 3
    PDL_DATA_AVAILABLE_FOR_MODIFICATION = 4

class PrintWorkflowSubmittedStatus(enum.IntEnum):
    SUCCEEDED = 0
    CANCELED = 1
    FAILED = 2

class PrintWorkflowUICompletionStatus(enum.IntEnum):
    COMPLETED = 0
    LAUNCH_FAILED = 1
    JOB_FAILED = 2
    USER_CANCELED = 3

Self = typing.TypeVar('Self')

class PrintWorkflowBackgroundSession(winsdk.system.Object):
    status: PrintWorkflowSessionStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowBackgroundSession: ...
    def start(self) -> None: ...
    def add_setup_requested(self, setup_event_handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowBackgroundSession, PrintWorkflowBackgroundSetupRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_setup_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_submitted(self, submitted_event_handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowBackgroundSession, PrintWorkflowSubmittedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_submitted(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintWorkflowBackgroundSetupRequestedEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowBackgroundSetupRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def get_user_print_ticket_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket]: ...
    def set_requires_u_i(self) -> None: ...

class PrintWorkflowConfiguration(winsdk.system.Object):
    job_title: str
    session_id: str
    source_app_display_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowConfiguration: ...
    def abort_print_flow(self, reason: PrintWorkflowJobAbortReason) -> None: ...

class PrintWorkflowForegroundSession(winsdk.system.Object):
    status: PrintWorkflowSessionStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowForegroundSession: ...
    def start(self) -> None: ...
    def add_setup_requested(self, setup_event_handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowForegroundSession, PrintWorkflowForegroundSetupRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_setup_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_xps_data_available(self, xps_data_available_event_handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowForegroundSession, PrintWorkflowXpsDataAvailableEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_xps_data_available(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintWorkflowForegroundSetupRequestedEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowForegroundSetupRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def get_user_print_ticket_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket]: ...

class PrintWorkflowJobActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    session: typing.Optional[PrintWorkflowJobUISession]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobActivatedEventArgs: ...

class PrintWorkflowJobBackgroundSession(winsdk.system.Object):
    status: PrintWorkflowSessionStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobBackgroundSession: ...
    def start(self) -> None: ...
    def add_job_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowJobBackgroundSession, PrintWorkflowJobStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_job_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_pdl_modification_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowJobBackgroundSession, PrintWorkflowPdlModificationRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_pdl_modification_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintWorkflowJobNotificationEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    printer_job: typing.Optional[PrintWorkflowPrinterJob]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobNotificationEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class PrintWorkflowJobStartingEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    printer: typing.Optional[winsdk.windows.devices.printers.IppPrintDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobStartingEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def set_skip_system_rendering(self) -> None: ...

class PrintWorkflowJobTriggerDetails(winsdk.system.Object):
    print_workflow_job_session: typing.Optional[PrintWorkflowJobBackgroundSession]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobTriggerDetails: ...

class PrintWorkflowJobUISession(winsdk.system.Object):
    status: PrintWorkflowSessionStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowJobUISession: ...
    def start(self) -> None: ...
    def add_job_notification(self, handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowJobUISession, PrintWorkflowJobNotificationEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_job_notification(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_pdl_data_available(self, handler: winsdk.windows.foundation.TypedEventHandler[PrintWorkflowJobUISession, PrintWorkflowPdlDataAvailableEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_pdl_data_available(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class PrintWorkflowObjectModelSourceFileContent(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowObjectModelSourceFileContent: ...
    def __new__(cls: typing.Type[PrintWorkflowObjectModelSourceFileContent], xps_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> PrintWorkflowObjectModelSourceFileContent:...

class PrintWorkflowObjectModelTargetPackage(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowObjectModelTargetPackage: ...

class PrintWorkflowPdlConverter(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPdlConverter: ...
    @typing.overload
    def convert_pdl_async(self, print_ticket: typing.Optional[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket], input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream], output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def convert_pdl_async(self, print_ticket: typing.Optional[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket], input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream], output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream], host_based_processing_operations: PdlConversionHostBasedProcessingOperations) -> winsdk.windows.foundation.IAsyncAction: ...

class PrintWorkflowPdlDataAvailableEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    printer_job: typing.Optional[PrintWorkflowPrinterJob]
    source_content: typing.Optional[PrintWorkflowPdlSourceContent]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPdlDataAvailableEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class PrintWorkflowPdlModificationRequestedEventArgs(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    printer_job: typing.Optional[PrintWorkflowPrinterJob]
    source_content: typing.Optional[PrintWorkflowPdlSourceContent]
    u_i_launcher: typing.Optional[PrintWorkflowUILauncher]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPdlModificationRequestedEventArgs: ...
    def create_job_on_printer(self, target_content_type: str) -> typing.Optional[PrintWorkflowPdlTargetStream]: ...
    @typing.overload
    def create_job_on_printer_with_attributes(self, job_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.windows.devices.printers.IppAttributeValue]], target_content_type: str) -> typing.Optional[PrintWorkflowPdlTargetStream]: ...
    @typing.overload
    def create_job_on_printer_with_attributes(self, job_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.windows.devices.printers.IppAttributeValue]], target_content_type: str, operation_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.windows.devices.printers.IppAttributeValue]], job_attributes_merge_policy: PrintWorkflowAttributesMergePolicy, operation_attributes_merge_policy: PrintWorkflowAttributesMergePolicy) -> typing.Optional[PrintWorkflowPdlTargetStream]: ...
    @typing.overload
    def create_job_on_printer_with_attributes_buffer(self, job_attributes_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], target_content_type: str) -> typing.Optional[PrintWorkflowPdlTargetStream]: ...
    @typing.overload
    def create_job_on_printer_with_attributes_buffer(self, job_attributes_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], target_content_type: str, operation_attributes_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], job_attributes_merge_policy: PrintWorkflowAttributesMergePolicy, operation_attributes_merge_policy: PrintWorkflowAttributesMergePolicy) -> typing.Optional[PrintWorkflowPdlTargetStream]: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def get_pdl_converter(self, conversion_type: PrintWorkflowPdlConversionType) -> typing.Optional[PrintWorkflowPdlConverter]: ...

class PrintWorkflowPdlSourceContent(winsdk.system.Object):
    content_type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPdlSourceContent: ...
    def get_content_file_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    def get_input_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...

class PrintWorkflowPdlTargetStream(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPdlTargetStream: ...
    def complete_stream_submission(self, status: PrintWorkflowSubmittedStatus) -> None: ...
    def get_output_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...

class PrintWorkflowPrinterJob(winsdk.system.Object):
    job_id: winsdk.system.Int32
    printer: typing.Optional[winsdk.windows.devices.printers.IppPrintDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowPrinterJob: ...
    def get_job_attributes(self, attribute_names: typing.Iterable[str]) -> typing.Optional[winsdk.windows.foundation.collections.IMap[str, winsdk.windows.devices.printers.IppAttributeValue]]: ...
    def get_job_attributes_as_buffer(self, attribute_names: typing.Iterable[str]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    def get_job_print_ticket(self) -> typing.Optional[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket]: ...
    def get_job_status(self) -> PrintWorkflowPrinterJobStatus: ...
    def set_job_attributes(self, job_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.windows.devices.printers.IppAttributeValue]]) -> typing.Optional[winsdk.windows.devices.printers.IppSetAttributesResult]: ...
    def set_job_attributes_from_buffer(self, job_attributes_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[winsdk.windows.devices.printers.IppSetAttributesResult]: ...

class PrintWorkflowSourceContent(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowSourceContent: ...
    def get_job_print_ticket_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket]: ...
    def get_source_spool_data_as_stream_content(self) -> typing.Optional[PrintWorkflowSpoolStreamContent]: ...
    def get_source_spool_data_as_xps_object_model(self) -> typing.Optional[PrintWorkflowObjectModelSourceFileContent]: ...

class PrintWorkflowSpoolStreamContent(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowSpoolStreamContent: ...
    def get_input_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...

class PrintWorkflowStreamTarget(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowStreamTarget: ...
    def get_output_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...

class PrintWorkflowSubmittedEventArgs(winsdk.system.Object):
    operation: typing.Optional[PrintWorkflowSubmittedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowSubmittedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def get_target(self, job_print_ticket: typing.Optional[winsdk.windows.graphics.printing.printticket.WorkflowPrintTicket]) -> typing.Optional[PrintWorkflowTarget]: ...

class PrintWorkflowSubmittedOperation(winsdk.system.Object):
    configuration: typing.Optional[PrintWorkflowConfiguration]
    xps_content: typing.Optional[PrintWorkflowSourceContent]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowSubmittedOperation: ...
    def complete(self, status: PrintWorkflowSubmittedStatus) -> None: ...

class PrintWorkflowTarget(winsdk.system.Object):
    target_as_stream: typing.Optional[PrintWorkflowStreamTarget]
    target_as_xps_object_model_package: typing.Optional[PrintWorkflowObjectModelTargetPackage]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowTarget: ...

class PrintWorkflowTriggerDetails(winsdk.system.Object):
    print_workflow_session: typing.Optional[PrintWorkflowBackgroundSession]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowTriggerDetails: ...

class PrintWorkflowUIActivatedEventArgs(winsdk.system.Object):
    kind: winsdk.windows.applicationmodel.activation.ActivationKind
    previous_execution_state: winsdk.windows.applicationmodel.activation.ApplicationExecutionState
    splash_screen: typing.Optional[winsdk.windows.applicationmodel.activation.SplashScreen]
    user: typing.Optional[winsdk.windows.system.User]
    print_workflow_session: typing.Optional[PrintWorkflowForegroundSession]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowUIActivatedEventArgs: ...

class PrintWorkflowUILauncher(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowUILauncher: ...
    def is_u_i_launch_enabled(self) -> winsdk.system.Boolean: ...
    def launch_and_complete_u_i_async(self) -> winsdk.windows.foundation.IAsyncOperation[PrintWorkflowUICompletionStatus]: ...

class PrintWorkflowXpsDataAvailableEventArgs(winsdk.system.Object):
    operation: typing.Optional[PrintWorkflowSubmittedOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintWorkflowXpsDataAvailableEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Globalization.NumberFormatting")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class CurrencyFormatterMode(enum.IntEnum):
    USE_SYMBOL = 0
    USE_CURRENCY_CODE = 1

class RoundingAlgorithm(enum.IntEnum):
    NONE = 0
    ROUND_DOWN = 1
    ROUND_UP = 2
    ROUND_TOWARDS_ZERO = 3
    ROUND_AWAY_FROM_ZERO = 4
    ROUND_HALF_DOWN = 5
    ROUND_HALF_UP = 6
    ROUND_HALF_TOWARDS_ZERO = 7
    ROUND_HALF_AWAY_FROM_ZERO = 8
    ROUND_HALF_TO_EVEN = 9
    ROUND_HALF_TO_ODD = 10

_ns_module._register_CurrencyFormatterMode(CurrencyFormatterMode)
_ns_module._register_RoundingAlgorithm(RoundingAlgorithm)

CurrencyFormatter = _ns_module.CurrencyFormatter
DecimalFormatter = _ns_module.DecimalFormatter
IncrementNumberRounder = _ns_module.IncrementNumberRounder
NumeralSystemTranslator = _ns_module.NumeralSystemTranslator
PercentFormatter = _ns_module.PercentFormatter
PermilleFormatter = _ns_module.PermilleFormatter
SignificantDigitsNumberRounder = _ns_module.SignificantDigitsNumberRounder
INumberFormatter = _ns_module.INumberFormatter
INumberFormatter2 = _ns_module.INumberFormatter2
INumberFormatterOptions = _ns_module.INumberFormatterOptions
INumberParser = _ns_module.INumberParser
INumberRounder = _ns_module.INumberRounder
INumberRounderOption = _ns_module.INumberRounderOption
ISignedZeroOption = _ns_module.ISignedZeroOption
ISignificantDigitsOption = _ns_module.ISignificantDigitsOption



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.System.Profile")


RetailMode = _ns_module.RetailMode



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.PersonalInformation")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class ContactChangeType(enum.IntEnum):
    CREATED = 0
    MODIFIED = 1
    DELETED = 2

class ContactQueryResultOrdering(enum.IntEnum):
    SYSTEM_DEFAULT = 0
    GIVEN_NAME_FAMILY_NAME = 1
    FAMILY_NAME_GIVEN_NAME = 2

class ContactStoreApplicationAccessMode(enum.IntEnum):
    LIMITED_READ_ONLY = 0
    READ_ONLY = 1

class ContactStoreSystemAccessMode(enum.IntEnum):
    READ_ONLY = 0
    READ_WRITE = 1

class VCardFormat(enum.IntEnum):
    VERSION2_1 = 0
    VERSION3 = 1

_ns_module._register_ContactChangeType(ContactChangeType)
_ns_module._register_ContactQueryResultOrdering(ContactQueryResultOrdering)
_ns_module._register_ContactStoreApplicationAccessMode(ContactStoreApplicationAccessMode)
_ns_module._register_ContactStoreSystemAccessMode(ContactStoreSystemAccessMode)
_ns_module._register_VCardFormat(VCardFormat)

ContactAddress = _ns_module.ContactAddress
ContactChangeRecord = _ns_module.ContactChangeRecord
ContactInformation = _ns_module.ContactInformation
ContactQueryOptions = _ns_module.ContactQueryOptions
ContactQueryResult = _ns_module.ContactQueryResult
ContactStore = _ns_module.ContactStore
KnownContactProperties = _ns_module.KnownContactProperties
StoredContact = _ns_module.StoredContact
IContactInformation = _ns_module.IContactInformation
IContactInformation2 = _ns_module.IContactInformation2



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.system

class ByteOrder(enum.IntEnum):
    LITTLE_ENDIAN = 0
    BIG_ENDIAN = 1

class FileOpenDisposition(enum.IntEnum):
    OPEN_EXISTING = 0
    OPEN_ALWAYS = 1
    CREATE_NEW = 2
    CREATE_ALWAYS = 3
    TRUNCATE_EXISTING = 4

class InputStreamOptions(enum.IntFlag):
    NONE = 0
    PARTIAL = 0x1
    READ_AHEAD = 0x2

class UnicodeEncoding(enum.IntEnum):
    UTF8 = 0
    UTF16_L_E = 1
    UTF16_B_E = 2

Self = typing.TypeVar('Self')

class Buffer(winsdk.system.Object):
    length: winsdk.system.UInt32
    capacity: winsdk.system.UInt32
    def __bytes__(self) -> bytes: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Buffer: ...
    def __new__(cls: typing.Type[Buffer], capacity: winsdk.system.UInt32) -> Buffer:...
    @staticmethod
    def create_copy_from_memory_buffer(input: typing.Optional[winsdk.windows.foundation.IMemoryBuffer]) -> typing.Optional[Buffer]: ...
    @staticmethod
    def create_memory_buffer_over_i_buffer(input: typing.Optional[IBuffer]) -> typing.Optional[winsdk.windows.foundation.MemoryBuffer]: ...

class DataReader(winsdk.system.Object):
    unicode_encoding: UnicodeEncoding
    input_stream_options: InputStreamOptions
    byte_order: ByteOrder
    unconsumed_buffer_length: winsdk.system.UInt32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataReader: ...
    def __new__(cls: typing.Type[DataReader], input_stream: typing.Optional[IInputStream]) -> DataReader:...
    def close(self) -> None: ...
    def detach_buffer(self) -> typing.Optional[IBuffer]: ...
    def detach_stream(self) -> typing.Optional[IInputStream]: ...
    @staticmethod
    def from_buffer(buffer: typing.Optional[IBuffer]) -> typing.Optional[DataReader]: ...
    def load_async(self, count: winsdk.system.UInt32) -> DataReaderLoadOperation: ...
    def read_boolean(self) -> winsdk.system.Boolean: ...
    def read_buffer(self, length: winsdk.system.UInt32) -> typing.Optional[IBuffer]: ...
    def read_byte(self) -> winsdk.system.UInt8: ...
    def read_bytes(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def read_date_time(self) -> datetime.datetime: ...
    def read_double(self) -> winsdk.system.Double: ...
    def read_guid(self) -> winsdk.system.Guid: ...
    def read_int16(self) -> winsdk.system.Int16: ...
    def read_int32(self) -> winsdk.system.Int32: ...
    def read_int64(self) -> winsdk.system.Int64: ...
    def read_single(self) -> winsdk.system.Single: ...
    def read_string(self, code_unit_count: winsdk.system.UInt32) -> str: ...
    def read_time_span(self) -> datetime.timedelta: ...
    def read_uint16(self) -> winsdk.system.UInt16: ...
    def read_uint32(self) -> winsdk.system.UInt32: ...
    def read_uint64(self) -> winsdk.system.UInt64: ...

class DataReaderLoadOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationCompletedHandler[winsdk.system.UInt32]]
    def __await__(self) -> typing.Generator[typing.Any, None, winsdk.system.UInt32]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataReaderLoadOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> winsdk.system.UInt32: ...

class DataWriter(winsdk.system.Object):
    unicode_encoding: UnicodeEncoding
    byte_order: ByteOrder
    unstored_buffer_length: winsdk.system.UInt32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataWriter: ...
    @typing.overload
    def __new__(cls: typing.Type[DataWriter], output_stream: typing.Optional[IOutputStream]) -> DataWriter:...
    @typing.overload
    def __new__(cls: typing.Type[DataWriter]) -> DataWriter:...
    def close(self) -> None: ...
    def detach_buffer(self) -> typing.Optional[IBuffer]: ...
    def detach_stream(self) -> typing.Optional[IOutputStream]: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def measure_string(self, value: str) -> winsdk.system.UInt32: ...
    def store_async(self) -> DataWriterStoreOperation: ...
    def write_boolean(self, value: winsdk.system.Boolean) -> None: ...
    @typing.overload
    def write_buffer(self, buffer: typing.Optional[IBuffer]) -> None: ...
    @typing.overload
    def write_buffer(self, buffer: typing.Optional[IBuffer], start: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def write_byte(self, value: winsdk.system.UInt8) -> None: ...
    def write_bytes(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def write_date_time(self, value: datetime.datetime) -> None: ...
    def write_double(self, value: winsdk.system.Double) -> None: ...
    def write_guid(self, value: winsdk.system.Guid) -> None: ...
    def write_int16(self, value: winsdk.system.Int16) -> None: ...
    def write_int32(self, value: winsdk.system.Int32) -> None: ...
    def write_int64(self, value: winsdk.system.Int64) -> None: ...
    def write_single(self, value: winsdk.system.Single) -> None: ...
    def write_string(self, value: str) -> winsdk.system.UInt32: ...
    def write_time_span(self, value: datetime.timedelta) -> None: ...
    def write_uint16(self, value: winsdk.system.UInt16) -> None: ...
    def write_uint32(self, value: winsdk.system.UInt32) -> None: ...
    def write_uint64(self, value: winsdk.system.UInt64) -> None: ...

class DataWriterStoreOperation(winsdk.system.Object):
    error_code: winsdk.windows.foundation.HResult
    id: winsdk.system.UInt32
    status: winsdk.windows.foundation.AsyncStatus
    completed: typing.Optional[winsdk.windows.foundation.AsyncOperationCompletedHandler[winsdk.system.UInt32]]
    def __await__(self) -> typing.Generator[typing.Any, None, winsdk.system.UInt32]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataWriterStoreOperation: ...
    def cancel(self) -> None: ...
    def close(self) -> None: ...
    def get_results(self) -> winsdk.system.UInt32: ...

class FileInputStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FileInputStream: ...
    def close(self) -> None: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...

class FileOutputStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FileOutputStream: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class FileRandomAccessStream(winsdk.system.Object):
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FileRandomAccessStream: ...
    def clone_stream(self) -> typing.Optional[IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IOutputStream]: ...
    @typing.overload
    @staticmethod
    def open_async(file_path: str, access_mode: winsdk.windows.storage.FileAccessMode) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStream]: ...
    @typing.overload
    @staticmethod
    def open_async(file_path: str, access_mode: winsdk.windows.storage.FileAccessMode, sharing_options: winsdk.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStream]: ...
    @typing.overload
    @staticmethod
    def open_for_user_async(user: typing.Optional[winsdk.windows.system.User], file_path: str, access_mode: winsdk.windows.storage.FileAccessMode) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStream]: ...
    @typing.overload
    @staticmethod
    def open_for_user_async(user: typing.Optional[winsdk.windows.system.User], file_path: str, access_mode: winsdk.windows.storage.FileAccessMode, sharing_options: winsdk.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStream]: ...
    @typing.overload
    @staticmethod
    def open_transacted_write_async(file_path: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageStreamTransaction]: ...
    @typing.overload
    @staticmethod
    def open_transacted_write_async(file_path: str, open_options: winsdk.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageStreamTransaction]: ...
    @typing.overload
    @staticmethod
    def open_transacted_write_for_user_async(user: typing.Optional[winsdk.windows.system.User], file_path: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageStreamTransaction]: ...
    @typing.overload
    @staticmethod
    def open_transacted_write_for_user_async(user: typing.Optional[winsdk.windows.system.User], file_path: str, open_options: winsdk.windows.storage.StorageOpenOptions, open_disposition: FileOpenDisposition) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageStreamTransaction]: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class InMemoryRandomAccessStream(winsdk.system.Object):
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InMemoryRandomAccessStream: ...
    def __new__(cls: typing.Type[InMemoryRandomAccessStream]) -> InMemoryRandomAccessStream:...
    def clone_stream(self) -> typing.Optional[IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class InputStreamOverStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InputStreamOverStream: ...
    def close(self) -> None: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...

class OutputStreamOverStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OutputStreamOverStream: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class RandomAccessStream(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RandomAccessStream: ...
    @staticmethod
    def copy_and_close_async(source: typing.Optional[IInputStream], destination: typing.Optional[IOutputStream]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt64, winsdk.system.UInt64]: ...
    @typing.overload
    @staticmethod
    def copy_async(source: typing.Optional[IInputStream], destination: typing.Optional[IOutputStream]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt64, winsdk.system.UInt64]: ...
    @typing.overload
    @staticmethod
    def copy_async(source: typing.Optional[IInputStream], destination: typing.Optional[IOutputStream], bytes_to_copy: winsdk.system.UInt64) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt64, winsdk.system.UInt64]: ...

class RandomAccessStreamOverStream(winsdk.system.Object):
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RandomAccessStreamOverStream: ...
    def clone_stream(self) -> typing.Optional[IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class RandomAccessStreamReference(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RandomAccessStreamReference: ...
    @staticmethod
    def create_from_file(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> typing.Optional[RandomAccessStreamReference]: ...
    @staticmethod
    def create_from_stream(stream: typing.Optional[IRandomAccessStream]) -> typing.Optional[RandomAccessStreamReference]: ...
    @staticmethod
    def create_from_uri(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> typing.Optional[RandomAccessStreamReference]: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStreamWithContentType]: ...

class IBuffer(winsdk.system.Object):
    capacity: winsdk.system.UInt32
    length: winsdk.system.UInt32
    def __bytes__(self) -> bytes: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IBuffer: ...

class IContentTypeProvider(winsdk.system.Object):
    content_type: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContentTypeProvider: ...

class IDataReader(winsdk.system.Object):
    byte_order: ByteOrder
    input_stream_options: InputStreamOptions
    unconsumed_buffer_length: winsdk.system.UInt32
    unicode_encoding: UnicodeEncoding
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IDataReader: ...
    def detach_buffer(self) -> typing.Optional[IBuffer]: ...
    def detach_stream(self) -> typing.Optional[IInputStream]: ...
    def load_async(self, count: winsdk.system.UInt32) -> DataReaderLoadOperation: ...
    def read_boolean(self) -> winsdk.system.Boolean: ...
    def read_buffer(self, length: winsdk.system.UInt32) -> typing.Optional[IBuffer]: ...
    def read_byte(self) -> winsdk.system.UInt8: ...
    def read_bytes(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def read_date_time(self) -> datetime.datetime: ...
    def read_double(self) -> winsdk.system.Double: ...
    def read_guid(self) -> winsdk.system.Guid: ...
    def read_int16(self) -> winsdk.system.Int16: ...
    def read_int32(self) -> winsdk.system.Int32: ...
    def read_int64(self) -> winsdk.system.Int64: ...
    def read_single(self) -> winsdk.system.Single: ...
    def read_string(self, code_unit_count: winsdk.system.UInt32) -> str: ...
    def read_time_span(self) -> datetime.timedelta: ...
    def read_uint16(self) -> winsdk.system.UInt16: ...
    def read_uint32(self) -> winsdk.system.UInt32: ...
    def read_uint64(self) -> winsdk.system.UInt64: ...

class IDataWriter(winsdk.system.Object):
    byte_order: ByteOrder
    unicode_encoding: UnicodeEncoding
    unstored_buffer_length: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IDataWriter: ...
    def detach_buffer(self) -> typing.Optional[IBuffer]: ...
    def detach_stream(self) -> typing.Optional[IOutputStream]: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def measure_string(self, value: str) -> winsdk.system.UInt32: ...
    def store_async(self) -> DataWriterStoreOperation: ...
    def write_boolean(self, value: winsdk.system.Boolean) -> None: ...
    @typing.overload
    def write_buffer(self, buffer: typing.Optional[IBuffer]) -> None: ...
    @typing.overload
    def write_buffer(self, buffer: typing.Optional[IBuffer], start: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def write_byte(self, value: winsdk.system.UInt8) -> None: ...
    def write_bytes(self, value: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def write_date_time(self, value: datetime.datetime) -> None: ...
    def write_double(self, value: winsdk.system.Double) -> None: ...
    def write_guid(self, value: winsdk.system.Guid) -> None: ...
    def write_int16(self, value: winsdk.system.Int16) -> None: ...
    def write_int32(self, value: winsdk.system.Int32) -> None: ...
    def write_int64(self, value: winsdk.system.Int64) -> None: ...
    def write_single(self, value: winsdk.system.Single) -> None: ...
    def write_string(self, value: str) -> winsdk.system.UInt32: ...
    def write_time_span(self, value: datetime.timedelta) -> None: ...
    def write_uint16(self, value: winsdk.system.UInt16) -> None: ...
    def write_uint32(self, value: winsdk.system.UInt32) -> None: ...
    def write_uint64(self, value: winsdk.system.UInt64) -> None: ...

class IInputStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IInputStream: ...
    def close(self) -> None: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...

class IInputStreamReference(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IInputStreamReference: ...
    def open_sequential_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[IInputStream]: ...

class IOutputStream(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IOutputStream: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class IPropertySetSerializer(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IPropertySetSerializer: ...
    def deserialize(self, property_set: typing.Optional[winsdk.windows.foundation.collections.IPropertySet], buffer: typing.Optional[IBuffer]) -> None: ...
    def serialize(self, property_set: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> typing.Optional[IBuffer]: ...

class IRandomAccessStream(winsdk.system.Object):
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    size: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IRandomAccessStream: ...
    def clone_stream(self) -> typing.Optional[IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class IRandomAccessStreamReference(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IRandomAccessStreamReference: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[IRandomAccessStreamWithContentType]: ...

class IRandomAccessStreamWithContentType(winsdk.system.Object):
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    size: winsdk.system.UInt64
    content_type: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IRandomAccessStreamWithContentType: ...
    def clone_stream(self) -> typing.Optional[IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[IBuffer], count: winsdk.system.UInt32, options: InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Foundation.Numerics")


Matrix3x2 = _ns_module.Matrix3x2
Matrix4x4 = _ns_module.Matrix4x4
Plane = _ns_module.Plane
Quaternion = _ns_module.Quaternion
Rational = _ns_module.Rational
Vector2 = _ns_module.Vector2
Vector3 = _ns_module.Vector3
Vector4 = _ns_module.Vector4



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.pwm.provider
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

class PwmPulsePolarity(enum.IntEnum):
    ACTIVE_HIGH = 0
    ACTIVE_LOW = 1

Self = typing.TypeVar('Self')

class PwmController(winsdk.system.Object):
    actual_frequency: winsdk.system.Double
    max_frequency: winsdk.system.Double
    min_frequency: winsdk.system.Double
    pin_count: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PwmController: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[PwmController]: ...
    @staticmethod
    def get_controllers_async(provider: typing.Optional[winsdk.windows.devices.pwm.provider.IPwmProvider]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[PwmController]]: ...
    @staticmethod
    def get_default_async() -> winsdk.windows.foundation.IAsyncOperation[PwmController]: ...
    @typing.overload
    @staticmethod
    def get_device_selector() -> str: ...
    @typing.overload
    @staticmethod
    def get_device_selector(friendly_name: str) -> str: ...
    def open_pin(self, pin_number: winsdk.system.Int32) -> typing.Optional[PwmPin]: ...
    def set_desired_frequency(self, desired_frequency: winsdk.system.Double) -> winsdk.system.Double: ...

class PwmPin(winsdk.system.Object):
    polarity: PwmPulsePolarity
    controller: typing.Optional[PwmController]
    is_started: winsdk.system.Boolean
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PwmPin: ...
    def close(self) -> None: ...
    def get_active_duty_cycle_percentage(self) -> winsdk.system.Double: ...
    def set_active_duty_cycle_percentage(self, duty_cycle_percentage: winsdk.system.Double) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Web.Http.Filters")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking.sockets
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.security.cryptography.certificates
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.web.http
except ImportError:
    pass

class HttpCacheReadBehavior(enum.IntEnum):
    DEFAULT = 0
    MOST_RECENT = 1
    ONLY_FROM_CACHE = 2
    NO_CACHE = 3

class HttpCacheWriteBehavior(enum.IntEnum):
    DEFAULT = 0
    NO_CACHE = 1

class HttpCookieUsageBehavior(enum.IntEnum):
    DEFAULT = 0
    NO_COOKIES = 1

_ns_module._register_HttpCacheReadBehavior(HttpCacheReadBehavior)
_ns_module._register_HttpCacheWriteBehavior(HttpCacheWriteBehavior)
_ns_module._register_HttpCookieUsageBehavior(HttpCookieUsageBehavior)

HttpBaseProtocolFilter = _ns_module.HttpBaseProtocolFilter
HttpCacheControl = _ns_module.HttpCacheControl
HttpServerCustomValidationRequestedEventArgs = _ns_module.HttpServerCustomValidationRequestedEventArgs
IHttpFilter = _ns_module.IHttpFilter
